@@ -7,8 +7,9 @@ from .clask_demo import *
 class ClaskTest(unittest.TestCase):
 
     def test_get(self):
-        query = {"name": "Tom", "age": 23}
-        print(get(query=query))
+        args = {"name": "Tom", "age": 23}
+        res = get(args=args)
+        print(res)
 
     def test_post1(self):
         data = {"name": "Jack", "age": 24}
@@ -18,9 +19,6 @@ class ClaskTest(unittest.TestCase):
         data = {"name": "Jack", "age": 24}
         print(post2(json=data))
 
-    def test_getStudent(self):
-        print(getStudent(uid=1, name='Tom'))
-
 
 if __name__ == '__main__':
     unittest.main()
